# Racket
Discord bot utilities.

I write discord bots for a small discord server with friends. This repo is a
collection of shared utilities I find myself re-writing for each bot.

I have no idea if these utilities would scale well to a large bot, or if they
are bug free. They work pretty well for our small-scale usage.